# Examples of statistical analyses in R
# Maximum pseudo likelihood estimation
# and minimum contrast estimation
# is used here


# par(mai=c(0.4,0.4,0.4,0.4))
library(spatstat)


# DATA 1: CELLS


# loading data
data(cells)
summary(cells)
plot(cells)


# L-function with envelopes
env = envelope(cells, fun = Lest, nsim = 39, correction = "border")
plot(env)


# fitting model - Strauss, MPL (we pretend we know that r=0.15)
model1 = ppm(cells, ~1, Strauss(r=0.15),method="mpl")
model1
summary(model1)
plot(model1, how = "image", main = c("Strauss model", "Conditional intensity plot"))
# many other Markov process are available, e.g. Poisson or pairwise


# fitting model - Strauss, maximum profile pseudo likelihood
s = data.frame(r=seq(0.05,0.20,by=0.01))
model2 = profilepl(s, Strauss, cells)
model2
summary(model2)
plot(model2)
model2$fit


# simulating model
Xsim <- rmh(model = model2$fit, start = list(n.start = 50),
            control = list(nrep = 10000))
plot(Xsim, main = "Simulation from fitted Strauss model")
summary(Xsim)


# model checking - visual comparison of simulation and data
par(mfrow=c(1,2))
Xsim <- rmh(model = model2$fit, start = list(n.start = 50),
            control = list(nrep = 10000))
plot(cells)
plot(Xsim)
par(mfrow=c(1,1))


# model checking - comparing F-functions
env = envelope(model2$fit, fun = Gest, nsim = 39)
plot(env)


# DATA 2: REDWOOD


# loading data
data(redwood)
summary(redwood)
plot(redwood)


# summary statistics - pcf
env = envelope(redwood, fun = pcf, nsim = 39)
plot(env,ylim=c(0,5))


# Estimating intensity using kernels
intensity = density.ppp(redwood,0.05)
plot(intensity)
points(redwood)


# fitting model - Thomas process, minimum contrast using K-function
model3 = thomas.estK(redwood)
plot(model3, main = c("Thomas process", "fit by minimum contrast"))
model3
# other processes available: lgcp.estK, matclust.estK


# simulate Thomas process
para = model3$modelpar
Xsim = rThomas(kappa=para[1], sigma=para[2], mu=para[3])
plot(Xsim)


# model checking - visual comparison between simulation and data
par(mfrow=c(1,2))
Xsim = rThomas(kappa=para[1], sigma=para[2], mu=para[3])
plot(redwood)
plot(Xsim)





